@@ -1,6 +1,6 @@
 /* textview.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2009 Ralf Hoffmann.
+ * Copyright (C) 2005-2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -600,6 +600,7 @@ void TextView::drawLineNumbers( int start_x, int end_x, int start_y, int lines )
         std::pair<int,int> real_line( -1, -1 );
 
         DrawableCont dc( _aguix, m_buffer );
+        int fg = _colors.getTextColor();
         
         if ( font == NULL ) elementHeight = _aguix->getCharHeight();
         else elementHeight = font->getCharHeight();
@@ -613,7 +614,7 @@ void TextView::drawLineNumbers( int start_x, int end_x, int start_y, int lines )
                 
                 w = ts.getAWidth().getWidth( buf );
                 
-                _aguix->DrawText( dc, font, buf, end_x - w - 5, i * elementHeight + start_y, 1 );
+                _aguix->DrawText( dc, font, buf, end_x - w - 5, i * elementHeight + start_y, fg );
             }
         }
         _aguix->unclip( font, &dc );
