@@ -1,6 +1,6 @@
 /* changelayoutop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009 Ralf Hoffmann.
+ * Copyright (C) 2009-2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -89,6 +89,7 @@ ChangeLayoutOp::save( Datei *fh )
     fh->configPutPairBool( "buttonsvertical", m_layout.getButtonVert() );
     fh->configPutPairBool( "listviewsvertical", m_layout.getListViewVert() );
     fh->configPutPairNum( "listviewweight", m_layout.getListViewWeight() );
+    fh->configPutPairBool( "weighttoactive", m_layout.getWeightRelToActive() );
     for ( it1 = m_layout.getOrders().begin();
           it1 != m_layout.getOrders().end();
           it1++ ) {
@@ -227,6 +228,7 @@ ChangeLayoutOp::configure()
     m_weight_sl = NULL;
     m_left_weight_b = NULL;
     m_right_weight_b = NULL;
+    m_weight_active_cb = NULL;
 
     int n, i;
     Text **texts;
@@ -235,7 +237,7 @@ ChangeLayoutOp::configure()
     m_lvv = m_layout.getListViewVert();
     
     // global container 1x3
-    m_ac1 = m_win->setContainer( new AContainer( m_win, 1, 7 ), true );
+    m_ac1 = m_win->setContainer( new AContainer( m_win, 1, 8 ), true );
     m_ac1->setMaxSpace( 5 );
     m_ac1->setBorderWidth( 5 );
     
@@ -342,7 +344,18 @@ ChangeLayoutOp::configure()
     m_weight_sl->setOffset( weight - 1 );
     updateWeightSlider();
 
-    AContainer *ac1_3 = m_ac1->add( new AContainer( m_win, 2, 1 ), 0, 6 );
+    m_weight_active_cb = (ChooseButton*)m_ac1->add( new ChooseButton( m_aguix,
+                                                                      0,
+                                                                      0,
+                                                                      20,
+                                                                      20,
+                                                                      ( m_layout.getWeightRelToActive() == true ) ? 1 : 0,
+                                                                      catalog.getLocale( 908 ),
+                                                                      LABEL_RIGHT,
+                                                                      1,
+                                                                      0 ), 0, 6, AContainer::CO_INCWNR );
+
+    AContainer *ac1_3 = m_ac1->add( new AContainer( m_win, 2, 1 ), 0, 7 );
     ac1_3->setMinSpace( 5 );
     ac1_3->setMaxSpace( -1 );
     ac1_3->setBorderWidth( 0 );
@@ -438,6 +451,8 @@ ChangeLayoutOp::configure()
         int o = m_weight_sl->getOffset();
         o = o + 1;
         m_layout.setListViewWeight( o );
+
+        m_layout.setWeightRelToActive( m_weight_active_cb->getState() );
     }
     
     if ( m_button_ac != NULL ) {
