@@ -204,190 +204,192 @@
      TERMINALWAIT_WCP = 420,
      SHOWOUTPUT_WCP = 421,
      VIEWSTR_WCP = 422,
-     INBACKGROUND_WCP = 423,
-     TAKEDIRS_WCP = 424,
-     ACTIONNUMBER_WCP = 425,
-     HIDDENFILES_WCP = 426,
-     HIDE_WCP = 427,
-     TOGGLE_WCP = 428,
-     FOLLOWSYMLINKS_WCP = 429,
-     MOVE_WCP = 430,
-     RENAME_WCP = 431,
-     SAMEDIR_WCP = 432,
-     REQUESTDEST_WCP = 433,
-     REQUESTFLAGS_WCP = 434,
-     OVERWRITE_WCP = 435,
-     ALWAYS_WCP = 436,
-     NEVER_WCP = 437,
-     COPYMODE_WCP = 438,
-     FAST_WCP = 439,
-     PRESERVEATTR_WCP = 440,
-     MODE_WCP = 441,
-     ACTIVE_WCP = 442,
-     ACTIVE2OTHER_WCP = 443,
-     SPECIAL_WCP = 444,
-     REQUEST_WCP = 445,
-     CURRENT_WCP = 446,
-     OTHER_WCP = 447,
-     FILTER_WCP = 448,
-     QUICK_WCP = 449,
-     ALSOACTIVE_WCP = 450,
-     RESETDIRSIZES_WCP = 451,
-     KEEPFILETYPES_WCP = 452,
-     RELATIVE_WCP = 453,
-     ONFILES_WCP = 454,
-     ONDIRS_WCP = 455,
-     SORTBY_WCP = 456,
-     SORTFLAG_WCP = 457,
-     REVERSE_WCP = 458,
-     DIRLAST_WCP = 459,
-     DIRMIXED_WCP = 460,
-     EXCLUDE_WCP = 461,
-     INCLUDE_WCP = 462,
-     UNSET_WCP = 463,
-     UNSETALL_WCP = 464,
-     SCRIPTOP_WCP = 465,
-     NOP_WCP = 466,
-     PUSH_WCP = 467,
-     LABEL_WCP = 468,
-     IF_WCP = 469,
-     END_WCP = 470,
-     POP_WCP = 471,
-     SETTINGS_WCP = 472,
-     WINDOW_WCP = 473,
-     GOTO_WCP = 474,
-     PUSHUSEOUTPUT_WCP = 475,
-     DODEBUG_WCP = 476,
-     WPURECURSIVE_WCP = 477,
-     WPUTAKEDIRS_WCP = 478,
-     STACKNR_WCP = 479,
-     PUSHSTRING_WCP = 480,
-     IFTEST_WCP = 481,
-     IFLABEL_WCP = 482,
-     WINTYPE_WCP = 483,
-     OPEN_WCP = 484,
-     CLOSE_WCP = 485,
-     LEAVE_WCP = 486,
-     CHANGEPROGRESS_WCP = 487,
-     CHANGETEXT_WCP = 488,
-     PROGRESSUSEOUTPUT_WCP = 489,
-     WINTEXTUSEOUTPUT_WCP = 490,
-     PROGRESS_WCP = 491,
-     WINTEXT_WCP = 492,
-     SHOWDIRCACHEOP_WCP = 493,
-     INODE_WCP = 494,
-     NLINK_WCP = 495,
-     BLOCKS_WCP = 496,
-     SHOWHEADER_WCP = 497,
-     LVHEADER_WCP = 498,
-     IGNORECASE_WCP = 499,
-     LISTVIEWS_WCP = 500,
-     BLL_WCP = 501,
-     LBL_WCP = 502,
-     LLB_WCP = 503,
-     BL_WCP = 504,
-     LB_WCP = 505,
-     LAYOUT_WCP = 506,
-     BUTTONSVERT_WCP = 507,
-     LISTVIEWSVERT_WCP = 508,
-     LISTVIEWWEIGHT_WCP = 509,
-     WEIGHTTOACTIVE_WCP = 510,
-     EXTCOND_WCP = 511,
-     USEEXTCOND_WCP = 512,
-     SUBTYPE_WCP = 513,
-     PARENTACTIONOP_WCP = 514,
-     NOOPERATIONOP_WCP = 515,
-     COLORMODE_WCP = 516,
-     DEFAULT_WCP = 517,
-     CUSTOM_WCP = 518,
-     UNSELECTCOLOR_WCP = 519,
-     SELECTCOLOR_WCP = 520,
-     UNSELECTACTIVECOLOR_WCP = 521,
-     SELECTACTIVECOLOR_WCP = 522,
-     COLOREXTERNPROG_WCP = 523,
-     PARENT_WCP = 524,
-     DONTCD_WCP = 525,
-     DONTCHECKVIRTUAL_WCP = 526,
-     GOFTPOP_WCP = 527,
-     HOSTNAME_WCP = 528,
-     USERNAME_WCP = 529,
-     PASSWORD_WCP = 530,
-     DONTENTERFTP_WCP = 531,
-     ALWAYSSTOREPW_WCP = 532,
-     INTERNALVIEWOP_WCP = 533,
-     CUSTOMFILES_WCP = 534,
-     SHOWMODE_WCP = 535,
-     SELECTED_WCP = 536,
-     REVERSESEARCH_WCP = 537,
-     MOUSECONF_WCP = 538,
-     SELECTBUTTON_WCP = 539,
-     ACTIVATEBUTTON_WCP = 540,
-     SCROLLBUTTON_WCP = 541,
-     SELECTMETHOD_WCP = 542,
-     ALTERNATIVE_WCP = 543,
-     SEARCHOP_WCP = 544,
-     EDITCOMMAND_WCP = 545,
-     SHOWPREVRESULTS_WCP = 546,
-     TEXTVIEW_WCP = 547,
-     TEXTVIEWHIGHLIGHTED_WCP = 548,
-     TEXTVIEWSELECTION_WCP = 549,
-     DIRBOOKMARKOP_WCP = 550,
-     OPENCONTEXTMENUOP_WCP = 551,
-     RUNCUSTOMACTION_WCP = 552,
-     CUSTOMNAME_WCP = 553,
-     CONTEXTBUTTON_WCP = 554,
-     ACTIVATEMOD_WCP = 555,
-     SCROLLMOD_WCP = 556,
-     CONTEXTMOD_WCP = 557,
-     NONE_WCP = 558,
-     CUSTOMACTION_WCP = 559,
-     SAVE_WORKER_STATE_ON_EXIT_WCP = 560,
-     OPENWORKERMENUOP_WCP = 561,
-     CHANGELABELOP_WCP = 562,
-     ASKFORLABEL_WCP = 563,
-     LABELCOLORS_WCP = 564,
-     BOOKMARKLABEL_WCP = 565,
-     BOOKMARKFILTER_WCP = 566,
-     SHOWONLYBOOKMARKS_WCP = 567,
-     SHOWONLYLABEL_WCP = 568,
-     SHOWALL_WCP = 569,
-     OPTIONMODE_WCP = 570,
-     INVERT_WCP = 571,
-     SET_WCP = 572,
-     CHANGEFILTERS_WCP = 573,
-     CHANGEBOOKMARKS_WCP = 574,
-     QUERYLABEL_WCP = 575,
-     MODIFYTABSOP_WCP = 576,
-     TABACTION_WCP = 577,
-     NEWTAB_WCP = 578,
-     CLOSECURRENTTAB_WCP = 579,
-     NEXTTAB_WCP = 580,
-     PREVTAB_WCP = 581,
-     CHANGELAYOUTOP_WCP = 582,
-     INFIXSEARCH_WCP = 583,
-     VOLUMEMANAGEROP_WCP = 584,
-     ERROR = 585,
-     ACTIVESIDE_WCP = 586,
-     SHOWFREESPACE_WCP = 587,
-     ACTIVEMODE_WCP = 588,
-     ASK_WCP = 589,
-     SSHALLOW_WCP = 590,
-     FIELD_WIDTH_WCP = 591,
-     QUICKSEARCHENABLED_WCP = 592,
-     FILTEREDSEARCHENABLED_WCP = 593,
-     XFTFONTS_WCP = 594,
-     USEMAGIC_WCP = 595,
-     MAGICPATTERN_WCP = 596,
-     MAGICCOMPRESSED_WCP = 597,
-     VOLUMEMANAGER_WCP = 598,
-     MOUNTCOMMAND_WCP = 599,
-     UNMOUNTCOMMAND_WCP = 600,
-     FSTABFILE_WCP = 601,
-     MTABFILE_WCP = 602,
-     PARTFILE_WCP = 603,
-     REQUESTACTION_WCP = 604,
-     STRING_WCP = 605,
-     NUM_WCP = 606
+     SHOWOUTPUTINT_WCP = 423,
+     INBACKGROUND_WCP = 424,
+     TAKEDIRS_WCP = 425,
+     ACTIONNUMBER_WCP = 426,
+     HIDDENFILES_WCP = 427,
+     HIDE_WCP = 428,
+     TOGGLE_WCP = 429,
+     FOLLOWSYMLINKS_WCP = 430,
+     MOVE_WCP = 431,
+     RENAME_WCP = 432,
+     SAMEDIR_WCP = 433,
+     REQUESTDEST_WCP = 434,
+     REQUESTFLAGS_WCP = 435,
+     OVERWRITE_WCP = 436,
+     ALWAYS_WCP = 437,
+     NEVER_WCP = 438,
+     COPYMODE_WCP = 439,
+     FAST_WCP = 440,
+     PRESERVEATTR_WCP = 441,
+     MODE_WCP = 442,
+     ACTIVE_WCP = 443,
+     ACTIVE2OTHER_WCP = 444,
+     SPECIAL_WCP = 445,
+     REQUEST_WCP = 446,
+     CURRENT_WCP = 447,
+     OTHER_WCP = 448,
+     FILTER_WCP = 449,
+     QUICK_WCP = 450,
+     ALSOACTIVE_WCP = 451,
+     RESETDIRSIZES_WCP = 452,
+     KEEPFILETYPES_WCP = 453,
+     RELATIVE_WCP = 454,
+     ONFILES_WCP = 455,
+     ONDIRS_WCP = 456,
+     SORTBY_WCP = 457,
+     SORTFLAG_WCP = 458,
+     REVERSE_WCP = 459,
+     DIRLAST_WCP = 460,
+     DIRMIXED_WCP = 461,
+     EXCLUDE_WCP = 462,
+     INCLUDE_WCP = 463,
+     UNSET_WCP = 464,
+     UNSETALL_WCP = 465,
+     SCRIPTOP_WCP = 466,
+     NOP_WCP = 467,
+     PUSH_WCP = 468,
+     LABEL_WCP = 469,
+     IF_WCP = 470,
+     END_WCP = 471,
+     POP_WCP = 472,
+     SETTINGS_WCP = 473,
+     WINDOW_WCP = 474,
+     GOTO_WCP = 475,
+     PUSHUSEOUTPUT_WCP = 476,
+     DODEBUG_WCP = 477,
+     WPURECURSIVE_WCP = 478,
+     WPUTAKEDIRS_WCP = 479,
+     STACKNR_WCP = 480,
+     PUSHSTRING_WCP = 481,
+     IFTEST_WCP = 482,
+     IFLABEL_WCP = 483,
+     WINTYPE_WCP = 484,
+     OPEN_WCP = 485,
+     CLOSE_WCP = 486,
+     LEAVE_WCP = 487,
+     CHANGEPROGRESS_WCP = 488,
+     CHANGETEXT_WCP = 489,
+     PROGRESSUSEOUTPUT_WCP = 490,
+     WINTEXTUSEOUTPUT_WCP = 491,
+     PROGRESS_WCP = 492,
+     WINTEXT_WCP = 493,
+     SHOWDIRCACHEOP_WCP = 494,
+     INODE_WCP = 495,
+     NLINK_WCP = 496,
+     BLOCKS_WCP = 497,
+     SHOWHEADER_WCP = 498,
+     LVHEADER_WCP = 499,
+     IGNORECASE_WCP = 500,
+     LISTVIEWS_WCP = 501,
+     BLL_WCP = 502,
+     LBL_WCP = 503,
+     LLB_WCP = 504,
+     BL_WCP = 505,
+     LB_WCP = 506,
+     LAYOUT_WCP = 507,
+     BUTTONSVERT_WCP = 508,
+     LISTVIEWSVERT_WCP = 509,
+     LISTVIEWWEIGHT_WCP = 510,
+     WEIGHTTOACTIVE_WCP = 511,
+     EXTCOND_WCP = 512,
+     USEEXTCOND_WCP = 513,
+     SUBTYPE_WCP = 514,
+     PARENTACTIONOP_WCP = 515,
+     NOOPERATIONOP_WCP = 516,
+     COLORMODE_WCP = 517,
+     DEFAULT_WCP = 518,
+     CUSTOM_WCP = 519,
+     UNSELECTCOLOR_WCP = 520,
+     SELECTCOLOR_WCP = 521,
+     UNSELECTACTIVECOLOR_WCP = 522,
+     SELECTACTIVECOLOR_WCP = 523,
+     COLOREXTERNPROG_WCP = 524,
+     PARENT_WCP = 525,
+     DONTCD_WCP = 526,
+     DONTCHECKVIRTUAL_WCP = 527,
+     GOFTPOP_WCP = 528,
+     HOSTNAME_WCP = 529,
+     USERNAME_WCP = 530,
+     PASSWORD_WCP = 531,
+     DONTENTERFTP_WCP = 532,
+     ALWAYSSTOREPW_WCP = 533,
+     INTERNALVIEWOP_WCP = 534,
+     CUSTOMFILES_WCP = 535,
+     SHOWMODE_WCP = 536,
+     SELECTED_WCP = 537,
+     REVERSESEARCH_WCP = 538,
+     MOUSECONF_WCP = 539,
+     SELECTBUTTON_WCP = 540,
+     ACTIVATEBUTTON_WCP = 541,
+     SCROLLBUTTON_WCP = 542,
+     SELECTMETHOD_WCP = 543,
+     ALTERNATIVE_WCP = 544,
+     SEARCHOP_WCP = 545,
+     EDITCOMMAND_WCP = 546,
+     SHOWPREVRESULTS_WCP = 547,
+     TEXTVIEW_WCP = 548,
+     TEXTVIEWHIGHLIGHTED_WCP = 549,
+     TEXTVIEWSELECTION_WCP = 550,
+     DIRBOOKMARKOP_WCP = 551,
+     OPENCONTEXTMENUOP_WCP = 552,
+     RUNCUSTOMACTION_WCP = 553,
+     CUSTOMNAME_WCP = 554,
+     CONTEXTBUTTON_WCP = 555,
+     ACTIVATEMOD_WCP = 556,
+     SCROLLMOD_WCP = 557,
+     CONTEXTMOD_WCP = 558,
+     NONE_WCP = 559,
+     CUSTOMACTION_WCP = 560,
+     SAVE_WORKER_STATE_ON_EXIT_WCP = 561,
+     OPENWORKERMENUOP_WCP = 562,
+     CHANGELABELOP_WCP = 563,
+     ASKFORLABEL_WCP = 564,
+     LABELCOLORS_WCP = 565,
+     BOOKMARKLABEL_WCP = 566,
+     BOOKMARKFILTER_WCP = 567,
+     SHOWONLYBOOKMARKS_WCP = 568,
+     SHOWONLYLABEL_WCP = 569,
+     SHOWALL_WCP = 570,
+     OPTIONMODE_WCP = 571,
+     INVERT_WCP = 572,
+     SET_WCP = 573,
+     CHANGEFILTERS_WCP = 574,
+     CHANGEBOOKMARKS_WCP = 575,
+     QUERYLABEL_WCP = 576,
+     MODIFYTABSOP_WCP = 577,
+     TABACTION_WCP = 578,
+     NEWTAB_WCP = 579,
+     CLOSECURRENTTAB_WCP = 580,
+     NEXTTAB_WCP = 581,
+     PREVTAB_WCP = 582,
+     CHANGELAYOUTOP_WCP = 583,
+     INFIXSEARCH_WCP = 584,
+     VOLUMEMANAGEROP_WCP = 585,
+     ERROR = 586,
+     ACTIVESIDE_WCP = 587,
+     SHOWFREESPACE_WCP = 588,
+     ACTIVEMODE_WCP = 589,
+     ASK_WCP = 590,
+     SSHALLOW_WCP = 591,
+     FIELD_WIDTH_WCP = 592,
+     QUICKSEARCHENABLED_WCP = 593,
+     FILTEREDSEARCHENABLED_WCP = 594,
+     XFTFONTS_WCP = 595,
+     USEMAGIC_WCP = 596,
+     MAGICPATTERN_WCP = 597,
+     MAGICCOMPRESSED_WCP = 598,
+     VOLUMEMANAGER_WCP = 599,
+     MOUNTCOMMAND_WCP = 600,
+     UNMOUNTCOMMAND_WCP = 601,
+     FSTABFILE_WCP = 602,
+     MTABFILE_WCP = 603,
+     PARTFILE_WCP = 604,
+     REQUESTACTION_WCP = 605,
+     SIZEH_WCP = 606,
+     STRING_WCP = 607,
+     NUM_WCP = 608
    };
 #endif
 
@@ -406,7 +408,7 @@ typedef union YYSTYPE
 
 
 /* Line 1676 of yacc.c  */
-#line 410 "configparser.tab.h"
+#line 412 "configparser.tab.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
