@@ -186,6 +186,7 @@ struct mytoken tokenlist[]={
   {START_WCP,"start"},
   {TERMINALWAIT_WCP,"terminalwait"},
   {SHOWOUTPUT_WCP,"showoutput"},
+  {SHOWOUTPUTINT_WCP,"showoutputint"},
   {VIEWSTR_WCP,"viewstr"},
   {INBACKGROUND_WCP,"inbackground"},
   {TAKEDIRS_WCP,"takedirs"},
@@ -368,7 +369,8 @@ struct mytoken tokenlist[]={
   { MTABFILE_WCP, "mtabfile" },
   { PARTFILE_WCP, "partfile" },
   { REQUESTACTION_WCP, "requestaction" },
-  { WEIGHTTOACTIVE_WCP, "weighttoactive" }
+  { WEIGHTTOACTIVE_WCP, "weighttoactive" },
+  { SIZEH_WCP, "sizeh" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
