@@ -1,6 +1,6 @@
 /* datei.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2007,2009 Ralf Hoffmann.
+ * Copyright (C) 2001-2007,2009-2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -658,6 +658,41 @@ char *Datei::createTMPName( const char *infix )
   return returnstr;
 }
 
+std::string Datei::createTMPHardlink( const std::string &name )
+{
+    std::string returnstr;
+    int rannr;
+    static int lfdnr = 0;
+    static MutEx lock;
+    
+    lock.lock();
+
+    for( int retry = 0; retry < 1000; retry++ ) {
+        rannr = rand();
+
+        returnstr = AGUIXUtils::formatStringToString( "%s/workerlnk%s%d%d",
+                                                      worker_tmpdir(),
+                                                      "",
+                                                      lfdnr++, rannr );
+        if ( Datei::lfileExistsExt( returnstr.c_str() ) == Datei::D_FE_NOFILE ) {
+            if ( worker_link( name.c_str(),
+                              returnstr.c_str() ) == 0 ) {
+                break;
+            } else {
+                if ( errno != EEXIST ) {
+                    returnstr = "";
+                    break;
+                }
+            }
+        }
+        returnstr = "";
+    }
+
+    lock.unlock();
+
+    return returnstr;
+}
+
 int Datei::putStringExt(const char *format,const char *str)
 {
   int written, size;
