@@ -1,6 +1,6 @@
 /* datei.h
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2008 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2008,2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,6 +24,7 @@
 
 #include "wdefines.h"
 #include <aguix/awidth.h>
+#include <string>
 
 class Datei
 {
@@ -66,6 +67,7 @@ public:
   static char *getFilenameFromPath(const char*);
   static char *getNameWithoutExt(const char*);
   static char *createTMPName( const char *infix = NULL );
+  static std::string createTMPHardlink( const std::string &name );
   static char *shrinkFilename( const char *str, int maxlength, AWidth &lencalc );
   static loff_t fileSize( const char * );
   static char *getRelativePath( const char *source, const char *destdir );
