@@ -1,6 +1,6 @@
 /* dirbookmarkui.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2007-2008 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2007-2008,2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -166,14 +166,80 @@ int DirBookmarkUI::mainLoop()
     {
         std::string start_entry = NWC::Path::join( m_dirname,
                                                    m_basename );
+        bool found = false;
+
         for ( int row = 0;; row++ ) {
             if ( m_lv->isValidRow( row ) == false ) break;
             if ( m_lv->getText( row, 0 ) == start_entry ) {
                 m_lv->setActiveRow( row );
                 m_lv->showActive();
+                found = true;
                 break;
             }
         }
+
+        if ( ! found ) {
+            /* first try to find an entry for which the start_entry
+               is a prefix */
+
+            int best_hit = -1;
+            std::string::size_type best_hit_length = 0;
+
+            for ( int row = 0;; row++ ) {
+                if ( m_lv->isValidRow( row ) == false ) break;
+
+                const std::string &entry_text = m_lv->getText( row, 0 );
+
+                if ( entry_text.length() > start_entry.length() ) {
+                    if ( entry_text.compare( 0,
+                                             start_entry.length(),
+                                             start_entry ) == 0 ) {
+                        if ( best_hit < 0 ||
+                             entry_text.length() < best_hit_length ) {
+                            best_hit = row;
+                            best_hit_length = entry_text.length();
+                        }
+                    }
+                }
+            }
+
+            if ( best_hit >= 0 ) {
+                m_lv->setActiveRow( best_hit );
+                m_lv->showActive();
+                found = true;
+            }
+        }
+
+        if ( ! found ) {
+            /* now try to find the largest prefix */
+
+            int best_hit = -1;
+            std::string::size_type best_hit_length = 0;
+
+            for ( int row = 0;; row++ ) {
+                if ( m_lv->isValidRow( row ) == false ) break;
+
+                const std::string &entry_text = m_lv->getText( row, 0 );
+
+                if ( entry_text.length() < start_entry.length() ) {
+                    if ( start_entry.compare( 0,
+                                              entry_text.length(),
+                                              entry_text ) == 0 ) {
+                        if ( best_hit < 0 ||
+                             entry_text.length() > best_hit_length ) {
+                            best_hit = row;
+                            best_hit_length = entry_text.length();
+                        }
+                    }
+                }
+            }
+
+            if ( best_hit >= 0 ) {
+                m_lv->setActiveRow( best_hit );
+                m_lv->showActive();
+                found = true;
+            }
+        }
     }
 
     for ( ; endmode == 0; ) {
