@@ -1,6 +1,6 @@
 /* fileentry.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2008 Ralf Hoffmann.
+ * Copyright (C) 2001-2008,2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -83,6 +83,7 @@ FileEntry::FileEntry()
   filetype=NULL;
   use=true;
   isHidden=false;
+  isCorrupt = false;
   
   reclistQueued = false;
   
@@ -150,62 +151,65 @@ int FileEntry::readInfos()
   return readInfos(false);
 }
 
-int FileEntry::readInfos(bool update)
+int FileEntry::readInfos( bool update )
 {
-  //TODO: auf update achten
-  worker_struct_stat stbuf;
+    //TODO: auf update achten
+    worker_struct_stat stbuf;
 
-  select=false;
-  dirsize=-1;
-  filetype=NULL;
+    select = false;
+    dirsize = -1;
+    filetype = NULL;
+    isCorrupt = false;
+    isLink = false;
 
-  if(fullname==NULL) return 1;
+    if ( fullname == NULL ) return 1;
 
-  memset( &statbuf, 0, sizeof( statbuf ) );
-  memset( &dstatbuf, 0, sizeof( dstatbuf ) );
+    memset( &statbuf, 0, sizeof( statbuf ) );
+    memset( &dstatbuf, 0, sizeof( dstatbuf ) );
 
-  if ( worker_lstat( fullname, &stbuf ) == 0 ) {
-    statbuf.size = stbuf.st_size;
-    statbuf.lastaccess = stbuf.st_atime;
-    statbuf.lastmod = stbuf.st_mtime;
-    statbuf.lastchange = stbuf.st_ctime;
-    statbuf.mode = stbuf.st_mode;
-    statbuf.userid = stbuf.st_uid;
-    statbuf.groupid = stbuf.st_gid;
-    statbuf.inode = stbuf.st_ino;
-    statbuf.nlink = stbuf.st_nlink;
-    statbuf.blocks = stbuf.st_blocks;
-    statbuf.rdev = stbuf.st_rdev;
-    statbuf.dev = stbuf.st_dev;
-  } else return 2;
-  isCorrupt=false;
-  if ( S_ISLNK( statbuf.mode ) ) {
-    isLink=true;
-    if ( worker_stat( fullname, &stbuf ) == 0 ) {
-      dstatbuf.size = stbuf.st_size;
-      dstatbuf.lastaccess = stbuf.st_atime;
-      dstatbuf.lastmod = stbuf.st_mtime;
-      dstatbuf.lastchange = stbuf.st_ctime;
-      dstatbuf.mode = stbuf.st_mode;
-      dstatbuf.userid = stbuf.st_uid;
-      dstatbuf.groupid = stbuf.st_gid;
-      dstatbuf.inode = stbuf.st_ino;
-      dstatbuf.nlink = stbuf.st_nlink;
-      dstatbuf.blocks = stbuf.st_blocks;
-      dstatbuf.rdev = stbuf.st_rdev;
-      dstatbuf.dev = stbuf.st_dev;
+    if ( worker_lstat( fullname, &stbuf ) == 0 ) {
+        statbuf.size = stbuf.st_size;
+        statbuf.lastaccess = stbuf.st_atime;
+        statbuf.lastmod = stbuf.st_mtime;
+        statbuf.lastchange = stbuf.st_ctime;
+        statbuf.mode = stbuf.st_mode;
+        statbuf.userid = stbuf.st_uid;
+        statbuf.groupid = stbuf.st_gid;
+        statbuf.inode = stbuf.st_ino;
+        statbuf.nlink = stbuf.st_nlink;
+        statbuf.blocks = stbuf.st_blocks;
+        statbuf.rdev = stbuf.st_rdev;
+        statbuf.dev = stbuf.st_dev;
     } else {
-      /* korrupt */
-      isCorrupt=true;
-      dstatbuf.mode = 0;  // to prevent corrupt links treated as dirs
-      if(errno==ENOENT) {
-        // Eventl. fuer spaetere Betrachtungen
-      }
+        isCorrupt = true;
+        return 2;
     }
-  } else {
-    isLink=false;
-  }
-  return 0;
+
+    if ( S_ISLNK( statbuf.mode ) ) {
+        isLink = true;
+        if ( worker_stat( fullname, &stbuf ) == 0 ) {
+            dstatbuf.size = stbuf.st_size;
+            dstatbuf.lastaccess = stbuf.st_atime;
+            dstatbuf.lastmod = stbuf.st_mtime;
+            dstatbuf.lastchange = stbuf.st_ctime;
+            dstatbuf.mode = stbuf.st_mode;
+            dstatbuf.userid = stbuf.st_uid;
+            dstatbuf.groupid = stbuf.st_gid;
+            dstatbuf.inode = stbuf.st_ino;
+            dstatbuf.nlink = stbuf.st_nlink;
+            dstatbuf.blocks = stbuf.st_blocks;
+            dstatbuf.rdev = stbuf.st_rdev;
+            dstatbuf.dev = stbuf.st_dev;
+        } else {
+            /* corrupt link */
+            isCorrupt = true;
+            dstatbuf.mode = 0;  // to prevent corrupt links treated as dirs
+            if ( errno == ENOENT ) {
+                // Eventl. fuer spaetere Betrachtungen
+            }
+        }
+    }
+    return 0;
 }
 
 char *FileEntry::getDestination() const
@@ -253,7 +257,7 @@ void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerType
   for ( int i = 0; i < (int)dis->size(); i++ ) {
     if ( i > 0 ) cur_field++;
     
-    switch( (*dis)[i]) {
+    switch( (*dis)[i] ) {
       case WorkerTypes::LISTCOL_NAME:
         s1 = "";
         if ( isLink == true ) {
@@ -278,6 +282,7 @@ void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerType
         lv->setText( row, cur_field, s1, true );
         break;
       case WorkerTypes::LISTCOL_SIZE:
+      case WorkerTypes::LISTCOL_SIZEH:
         if ( S_ISCHR( statbuf.mode ) ||
              S_ISBLK( statbuf.mode ) ) {
           x = (int)statbuf.rdev;
@@ -303,8 +308,13 @@ void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerType
             s1 = wconfig->getStringForDirSize();
             lv->setText( row, cur_field, s1 );
           } else {
-	    MakeLong2NiceStr( dissize, s1 );
-            lv->setText( row, cur_field, s1 );
+              if ( (*dis)[i] == WorkerTypes::LISTCOL_SIZEH ) {
+                  s1 = AGUIXUtils::bytes_to_human_readable_f( dissize, 1, 0 );
+                  lv->setText( row, cur_field, s1 );
+              } else {
+                  MakeLong2NiceStr( dissize, s1 );
+                  lv->setText( row, cur_field, s1 );
+              }
           }
         }
         break;
@@ -509,12 +519,13 @@ const char *FileEntry::getPermissionString()
 
   if ( isLink == true ) str[0] = 'l';
   else {
-    if ( S_ISDIR( statbuf.mode ) ) str[0] = 'd';
-    else if ( S_ISFIFO( statbuf.mode ) ) str[0] = 'p';
-    else if ( S_ISSOCK( statbuf.mode ) ) str[0] = 's';
-    else if ( S_ISCHR( statbuf.mode ) ) str[0] = 'c';
-    else if ( S_ISBLK( statbuf.mode ) ) str[0] = 'b';
-    else str[0] = '-';
+      if ( isCorrupt ) str[0] = '?';
+      else if ( S_ISDIR( statbuf.mode ) ) str[0] = 'd';
+      else if ( S_ISFIFO( statbuf.mode ) ) str[0] = 'p';
+      else if ( S_ISSOCK( statbuf.mode ) ) str[0] = 's';
+      else if ( S_ISCHR( statbuf.mode ) ) str[0] = 'c';
+      else if ( S_ISBLK( statbuf.mode ) ) str[0] = 'b';
+      else str[0] = '-';
   }
   if ( ( statbuf.mode & S_IRUSR ) == S_IRUSR ) str[1] = 'r'; else str[1] = '-';
   if ( ( statbuf.mode & S_IWUSR ) == S_IWUSR ) str[2] = 'w'; else str[2] = '-';
@@ -578,292 +589,6 @@ bool FileEntry::isExe( bool fastTest ) const
   return false;
 }
 
-FileEntry::typecandidate_t FileEntry::runTests( WCFiletype *type,
-						bool skipcontent,
-						CondParser *condparser,
-						unsigned char fbuffer[64],
-						int reads,
-                                                typecheck_temp_results_t &temp_results )
-{
-  typecandidate_t erg;
-  int minsize, x, y;
-  char *tstr1;
-  
-  if ( type == NULL ) return erg;
-  if ( condparser == NULL ) return erg;
-  
-  if ( skipcontent == false ) {
-    short *filedesc;
-    if ( type->getinternID() == NORMALTYPE ) {
-      if ( type->getUseFiledesc() == true ) {
-	erg.tests_done++;
-	if ( reads > 0 ) {
-	  filedesc = type->getFiledesc();
-	  minsize = 0;
-	  for ( x = 0; x < 64; x++ ) {
-	    if ( filedesc[x] > -1 ) minsize = x + 1;
-	  }
-	  if ( ( reads >= minsize ) && ( minsize > 0 ) ) {
-	    y = 0;
-	    for ( x = 0; x < reads; x++ ) {
-	      if ( filedesc[x] >= 0 ) {
-		if ( filedesc[x] != (short)fbuffer[x] ) {
-		  y = 1;
-		  break;
-		}
-	      }
-	    }
-	    if ( y == 0 ) {
-	      erg.prio = 3;
-	      erg.type = type;
-	    }
-	  }
-	}
-      }
-
-      if ( erg.type == NULL && type->getUseMagic() == true ) {
-          erg.tests_done++;
-          if ( type->getMagicCompressed() == true ) {
-              if ( temp_results.magic_avail_compressed == false ) {
-                  if ( worker_islocal( fullname ) == true ) {
-                      temp_results.magic_result_compressed = MagicDB::getInstance().getInfo( fullname, true );
-                  } else {
-                      temp_results.magic_result_compressed = MagicDB::getInstance().getInfo( fbuffer, reads, true );
-                  }
-                  temp_results.magic_avail_compressed = true;
-              }
-          } else {
-              if ( temp_results.magic_avail == false ) {
-                  if ( worker_islocal( fullname ) == true ) {
-                      temp_results.magic_result = MagicDB::getInstance().getInfo( fullname );
-                  } else {
-                      temp_results.magic_result = MagicDB::getInstance().getInfo( fbuffer, reads );
-                  }
-                  temp_results.magic_avail = true;
-              }
-          }
-
-          if ( type->magicMatch( ( type->getMagicCompressed() == true ) ?
-                                 temp_results.magic_result_compressed :
-                                 temp_results.magic_result ) == true ) {
-              erg.prio = 3;
-              erg.type = type;
-          }
-      }
-    }
-  }
-
-  /* if no type found then check extended pattern */
-  if ( erg.type == NULL ) {
-    if ( type->getinternID() == NORMALTYPE ) {
-      if ( type->getUseExtCond() == true ) {
-	erg.tests_done++;
-	condparser->setIgnoreContent( skipcontent );
-	if ( condparser->parse( type->getExtCond(), this ) == 1 ) {
-	  erg.prio = 2;
-	  erg.type = type;
-	}
-      }
-    }
-  }
-
-  /* if no type found then check the pattern */
-  if ( erg.type == NULL ) {
-    if ( type->getinternID() == NORMALTYPE ) {
-      if ( type->getUsePattern() == true ) {
-	erg.tests_done++;
-	if ( type->getPatternUseFullname() == true ) {
-	  tstr1 = fullname;
-	} else {
-	  tstr1 = name;
-	}
-	if ( type->patternMatchString( tstr1 ) == true ) {
-	  erg.prio = 1;
-	  erg.type = type;
-	}
-      }
-    }
-  }
-  return erg;
-}
-
-FileEntry::typecandidate_t FileEntry::checkFiletype( const std::list<WCFiletype*> *ftlist,
-						     bool skipcontent,
-						     CondParser *condparser,
-						     unsigned char fbuffer[64],
-						     int reads,
-                                                     typecheck_temp_results_t &temp_results )
-{
-  WCFiletype *ft;
-  typecandidate_t cand1, erg, cand2;
-  const std::list<WCFiletype*> *subtypes;
-  std::list<WCFiletype*>::const_iterator it1;
-
-  if ( ftlist == NULL ) return erg;
-  if ( condparser == NULL ) return erg;
-  if ( fbuffer == NULL ) return erg;
-  
-  if ( ftlist->size() < 1 ) {
-    return erg;
-  }
-  if ( ( S_ISDIR( statbuf.mode ) ) && ( isCorrupt == false ) ) {
-    // Wirklich ein Verzeichnis
-    return erg;
-  }
-  
-  for ( it1 = ftlist->begin(); it1 != ftlist->end(); it1++ ) {
-    ft = *it1;
-    cand1 = runTests( ft, skipcontent, condparser, fbuffer, reads, temp_results );
-    if ( ( cand1.type != NULL ) || ( cand1.tests_done < 1 ) ) {
-      // check subtypes if we had a hit or did no tests
-      subtypes = ft->getSubTypeList();
-      if ( subtypes != NULL ) {
-	if ( subtypes->size() > 0 ) {
-            cand2 = checkFiletype( subtypes, skipcontent, condparser, fbuffer, reads, temp_results );
-	  if ( cand2.prio > 0 ) {
-	    // subtypes are always more important
-	    cand1.prio = cand2.prio;
-	    cand1.type = cand2.type;
-	  }
-	}
-      }
-    }
-    if ( cand1.type != NULL ) {
-      if ( cand1.prio > erg.prio ) {
-	erg.prio = cand1.prio;
-	erg.type = cand1.type;
-      }
-    }
-  }
-
-  return erg;
-}
-
-WCFiletype* FileEntry::checkFiletype( List *ftlist, bool skipcontent, CondParser *condparser )
-{
-  unsigned char fbuffer[64];
-  int reads = 0;
-  int id;
-  WCFiletype *ft,*unknownft;
-  CondParser *localparser = NULL;
-  PDatei *pfp;
-  typecandidate_t cand1, erg, cand2;
-  const std::list<WCFiletype*> *subtypes;
-  typecheck_temp_results_t temp_results;
-
-  if ( ftlist == NULL ) return NULL;
-  
-  // TODO: Momentan durchsuche ich jedesmal die Liste nach unknowntyp
-  //       Da ich nun dazubergegangen bin, die Position nicht mehr zu
-  //       garantieren, muss ich suchen
-  //       Vielleicht wre eine Variable mglich die bei nderung der Liste 
-  //       gendert wird und so Sofortzugriff erlaubt
-  //       wconfig->getunknowntype() geht AUF JEDEN FALL nicht, die ftlist
-  //       NICHT die gleiche wie im wconfig ist (wegen Thread-behandlung)
-  //       (zumindest im Moment nicht, bei einer thread-safe liste und FTs
-  //        knnte dies wieder zurckgenommen werden)
-  id = ftlist->initEnum();
-  unknownft = (WCFiletype*)ftlist->getFirstElement( id );
-  while ( unknownft != NULL ) {
-    if ( unknownft->getinternID() == UNKNOWNTYPE ) break;
-    unknownft = (WCFiletype*)ftlist->getNextElement( id );
-  }
-  ftlist->closeEnum( id );
-  // Vorbesetzen, damit immer unknown typ kommt, selbst wenn Datei nicht den Anforderungen
-  //  fuer Dateityperkennung genuegt
-  filetype=unknownft;
-  if(ftlist->size()<4) {
-    return filetype;
-  }
-  if ( ( S_ISDIR( statbuf.mode ) ) && ( isCorrupt == false ) ) {
-    // Wirklich ein Verzeichnis
-    return filetype;
-  }
-  
-  if ( isReg() == false ) skipcontent = true;
-  if ( statbuf.size < 1 ) skipcontent = true;
-
-  if(skipcontent==false) {
-    reads = -1;
-    pfp = new PDatei();
-    if ( pfp->open( fullname ) == 0 ) {
-      reads = pfp->read( fbuffer, 64 );
-    }
-    delete pfp;
-  }
-
-  if ( condparser == NULL ) {
-    localparser = new CondParser();
-    condparser = localparser;
-  }
-
-  id = ftlist->initEnum();
-  ft = (WCFiletype*)ftlist->getFirstElement( id );
-  while ( ft != NULL ) {
-      cand1 = runTests( ft, skipcontent, condparser, fbuffer, reads, temp_results );
-    if ( ( cand1.type != NULL ) || ( cand1.tests_done < 1 ) ) {
-      // check subtypes if we had a hit or did no tests
-      subtypes = ft->getSubTypeList();
-      if ( subtypes != NULL ) {
-	if ( subtypes->size() > 0 ) {
-            cand2 = checkFiletype( subtypes, skipcontent, condparser, fbuffer, reads, temp_results );
-	  if ( cand2.prio > 0 ) {
-	    // subtypes are always more important
-	    cand1.prio = cand2.prio;
-	    cand1.type = cand2.type;
-	  }
-	}
-      }
-    }
-    if ( cand1.type != NULL ) {
-      if ( cand1.prio > erg.prio ) {
-	erg.prio = cand1.prio;
-	erg.type = cand1.type;
-      }
-    }
-    ft = (WCFiletype*)ftlist->getNextElement( id );
-  }
-
-  if ( erg.type  == NULL ) {
-    filetype = unknownft;
-  } else {
-    filetype = erg.type;
-  }
-  ftlist->closeEnum( id );
-  
-  if ( filetype != NULL ) {
-    ft = filetype;
-    while ( ft->getColorMode() == ft->PARENTCOL ) {
-      ft = ft->getParentType();
-      if ( ft == NULL ) break;
-    }
-    if ( ft != NULL ) {
-      if ( ft->getColorMode() == ft->CUSTOMCOL ) {
-          m_colors.setCustomColors( ft->getCustomColor( 0 ),
-                                    ft->getCustomColor( 1 ) );
-      } else if ( ft->getColorMode() == ft->EXTERNALCOL ) {
-	char *o1 = condparser->getOutput( ft->getColorExt(), this );
-	int tfg[4], tbg[4], z;
-
-	if ( o1 != NULL ) {
-	  z = sscanf( o1, "%d %d %d %d %d %d %d %d", &tfg[0], &tbg[0], &tfg[1], &tbg[1], &tfg[2], &tbg[2], &tfg[3], &tbg[3] );
-	  if ( z == 8 ) {
-              m_colors.setCustomColors( tfg, tbg );
-	  }
-	  _freesafe( o1 );
-	}
-      }
-    }
-  }
-
-  // free temporary buffers
-  if ( localparser != NULL ) delete localparser;
-  freeContentBuf();
-  freeOutputBuf();
-  
-  return filetype;
-}
-
 bool FileEntry::match(char* pattern)
 {
   if(fnmatch(pattern,name,0)==0) return true;
@@ -1138,6 +863,7 @@ int FileEntry::findOutputAndRV( const char *tcommand,
 bool FileEntry::isReg() const
 {
   if ( isLink == false ) {
+    if ( isCorrupt == true ) return false;
     if ( S_ISREG( statbuf.mode ) ) return true;
     else return false;
   }
@@ -1151,6 +877,11 @@ void FileEntry::setCustomColor( const FileEntryCustomColor &c )
     m_colors.setCustomColor( c );
 }
 
+void FileEntry::setCustomColors( const int fg[4], const int bg[4] )
+{
+    m_colors.setCustomColors( fg, bg );
+}
+
 const FileEntryCustomColor &FileEntry::getCustomColor() const throw ( int )
 {
     return m_colors.getCustomColor();
