@@ -1,6 +1,6 @@
 /* fileviewer.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006-2008 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2006-2008,2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -314,8 +314,8 @@ int FileViewer::buildTextView( const std::string &filename,
       std::string l1, l2;
       int cancel_button;
 
-      l1 = AGUIXUtils::bytes_to_human_readable( file_length );
-      l2 = AGUIXUtils::bytes_to_human_readable( initial_size );
+      l1 = AGUIXUtils::bytes_to_human_readable_f( file_length );
+      l2 = AGUIXUtils::bytes_to_human_readable_f( (double)initial_size );
 
       char *textstr = (char*)_allocsafe( strlen( catalog.getLocale( 764 ) ) +
                                          l1.length() + l2.length() + 1 );
