@@ -1,6 +1,6 @@
 /* hw_volume_manager.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009 Ralf Hoffmann.
+ * Copyright (C) 2009-2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -238,6 +238,28 @@ void HWVolumeManager::update( HWVolume &vol )
             vol.setMountPoint( "" );
         }
         
+        try {
+            std::string label;
+            
+            label = getStringProperty( vol.getUDI().c_str(), "volume.label" );
+            
+            if ( ! label.empty() ) {
+                vol.setLabel( label );
+            }
+        } catch ( int ) {
+        }
+
+        try {
+            loff_t size;
+            
+            size = getUint64Property( vol.getUDI().c_str(), "volume.size" );
+            
+            if ( size != 0 ) {
+                vol.setSize( size );
+            }
+        } catch ( int ) {
+        }
+
         std::string device;
         try {
             device = getStringProperty( vol.getUDI().c_str(),
@@ -466,6 +488,28 @@ std::string HWVolumeManager::getStringProperty( const std::string &udi,
 #endif
 }
 
+loff_t HWVolumeManager::getUint64Property( const std::string &udi,
+                                           const std::string &property )
+{
+#ifdef HAVE_HAL_DBUS
+    if ( ! m_hal_ctx ) throw 1;
+
+    if ( ! libhal_device_property_exists( m_hal_ctx, udi.c_str(),
+                                          property.c_str(),
+                                          NULL ) ) {
+        throw 2;
+    }
+
+    dbus_uint64_t val1 = 0;
+    val1 = libhal_device_get_property_uint64( m_hal_ctx, udi.c_str(),
+                                              property.c_str(), NULL );
+    //TODO some error handling would be good
+    return (loff_t)val1;
+#else
+    throw -1;
+#endif
+}
+
 std::list< std::string > HWVolumeManager::getStrlistProperty( const std::string &udi,
                                                               const std::string &property )
 {
