@@ -1,6 +1,6 @@
 /* normalmode.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2009 Ralf Hoffmann.
+ * Copyright (C) 2001-2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -105,7 +105,8 @@ public:
   enum {NM_EXT_START_NORMAL=0,
         NM_EXT_START_IN_TERMINAL,
         NM_EXT_START_IN_TERMINAL_AND_WAIT4KEY,
-        NM_EXT_SHOW_OUTPUT} extstart;
+        NM_EXT_SHOW_OUTPUT,
+        NM_EXT_SHOW_OUTPUT_INT } extstart;
 
   char *com_str;
   char *view_str;
@@ -624,7 +625,6 @@ protected:
   bool visChanged;
   int oldlvy;
   
-  void showInvalidList( ArrayList *list, const char *descr );
   void changeSortModeForField( int field );
   
   int busyFlag;
@@ -709,10 +709,10 @@ protected:
 
     std::list<PopUpMenu::PopUpEntry> buildLabelPopUpData( FileEntry *entry );
     void handleLabelPopUp( AGMessage *msg );
-    void handleLabelPopUp( FileEntry *fe, const std::list<int> &entry_ids );
+    void handleLabelPopUp( FileEntry *fe, const std::list<int> &entry_ids, AGMessage *msg );
 
     typedef struct _label_popup_table_t {
-        typedef enum { REMOVE_LABEL, ADD_LABEL } label_popup_t;
+        typedef enum { REMOVE_LABEL, ADD_LABEL, ADD_CUSTOM_LABEL } label_popup_t;
 
         _label_popup_table_t() : type( REMOVE_LABEL ),
                                  label( "" )
