@@ -1,6 +1,6 @@
 /* setfilterop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2008 Ralf Hoffmann.
+ * Copyright (C) 2001-2004,2008,2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -26,6 +26,8 @@
 #include <aguix/acontainerbb.h>
 #include "bookmarkdbproxy.hh"
 #include <algorithm>
+#include "workerinitialsettings.hh"
+#include "nwc_path.hh"
 
 const char *SetFilterOp::name="SetFilterOp";
 int SetFilterOp::instance_counter = 0;
@@ -749,13 +751,11 @@ void SetFilterOp::initHistory()
 
   filter_history = new List();
 
-  tstr = getenv( "HOME" );
-  if ( tstr != NULL ) {
-    str1 = tstr;
-    str1 += "/.worker/setfilter-history";
-    fp->open( str1.c_str(), "r" );
-    
-    while ( fp->isEOF() == false ) {
+  str1 = WorkerInitialSettings::getInstance().getConfigBaseDir();
+  str1 = NWC::Path::join( str1, "setfilter-history" );
+  fp->open( str1.c_str(), "r" );
+  
+  while ( fp->isEOF() == false ) {
       tstr = fp->getLine();
       if ( tstr == NULL ) break;
       if ( strlen( tstr ) > 0 ) {
@@ -763,10 +763,9 @@ void SetFilterOp::initHistory()
       } else {
         _freesafe( tstr );
       }
-    }
-    
-    fp->close();
   }
+  
+  fp->close();
   delete fp;
 }
 
@@ -778,8 +777,8 @@ void SetFilterOp::closeHistory()
   Datei *fp = new Datei();
   std::string str1;
 
-  str1 = wconfig->getHome();
-  str1 += "/setfilter-history";
+  str1 = WorkerInitialSettings::getInstance().getConfigBaseDir();
+  str1 = NWC::Path::join( str1, "setfilter-history" );
   fp->open( str1.c_str(), "w" );
   
   id = filter_history->initEnum();
