@@ -34,7 +34,6 @@ Verzeichnis::Verzeichnis() : _dir_opened( false ),
                              _highest_ID_plus_one( 0 ),
                              _id_serial( -1 )
 {
-    invalid_entries = NULL;
 }
 
 Verzeichnis::~Verzeichnis()
@@ -42,7 +41,7 @@ Verzeichnis::~Verzeichnis()
     closeDir();
 }
 
-int Verzeichnis::readDir( const char *dirstr, bool dontWarnInvalid )
+int Verzeichnis::readDir( const char *dirstr )
 {
     if ( dirstr == NULL ) return -1;
     if ( strlen( dirstr ) < 1 ) return -1;
@@ -55,13 +54,10 @@ int Verzeichnis::readDir( const char *dirstr, bool dontWarnInvalid )
     const char *myerror;
     std::string str1;
     
-    invalid_entries = new std::vector<FileEntry*>();
-    
     _files.clear();
     
     dir = worker_opendir( dirstr );
     if ( dir != NULL ) {
-        bool user_abort = false;
         worker_struct_dirent *namelist;
 
         // first create .. entry
@@ -104,60 +100,20 @@ int Verzeichnis::readDir( const char *dirstr, bool dontWarnInvalid )
                 str1 = NWC::Path::join( dirstr, fe1->name );
                 fe1->fullname = dupstring( str1.c_str() );
               
-                if ( fe1->readInfos() == 0 ) {
-                    if ( fe1->name[0] == '.' )
-                        fe1->isHidden = true;
-                    else
-                        fe1->isHidden = false;
-                    _files.push_back( fe1 );
-                } else {
-                    myerror = strerror( errno );
-                    if ( ( Worker::getRequester() != NULL ) && ( dontWarnInvalid == false ) ) {
-                        char *tstr2 = (char*)_allocsafe( strlen( catalog.getLocale( 531 ) ) +
-                                                         strlen( fe1->fullname ) +
-                                                         strlen( myerror ) + 1 );
-                        sprintf( tstr2, catalog.getLocale( 531 ), fe1->fullname, myerror );
-                        str1 = catalog.getLocale( 11 );
-                        str1 += "|";
-                        str1 += catalog.getLocale( 8 );
-                      
-                        int erg = Worker::getRequester()->request( catalog.getLocale( 347 ), tstr2, str1.c_str() );
-                        _freesafe( tstr2 );
-                        if ( erg == 1 ) {
-                            user_abort = true;
-                        }
-                    }
-                  
-                    invalid_entries->push_back( fe1 );
+                if ( fe1->readInfos() != 0 ) {
                 }
+
+                if ( fe1->name[0] == '.' )
+                    fe1->isHidden = true;
+                else
+                    fe1->isHidden = false;
+                _files.push_back( fe1 );
             }
-            if ( user_abort == true ) break;
         }
         worker_closedir( dir );
       
-        if ( user_abort == true ) {
-            for ( verz_it fe1_it1 = _files.begin();
-                  fe1_it1 != _files.end();
-                  fe1_it1++ ) {
-                delete *fe1_it1;
-            }
-          
-            _files.clear();
-            _dir_opened = false;
-          
-            for ( std::vector<FileEntry*>::iterator fe_it2 = invalid_entries->begin();
-                  fe_it2 != invalid_entries->end();
-                  fe_it2++ ) {
-                delete *fe_it2;
-            }
-          
-            returnvalue = 1;
-            delete invalid_entries;
-            invalid_entries = NULL;
-        } else {
-            _dir_opened = true;
-            _dir_name = dirstr;
-        }
+        _dir_opened = true;
+        _dir_name = dirstr;
     } else {
         // requester: can't read directory
         myerror = strerror( errno );
@@ -172,9 +128,6 @@ int Verzeichnis::readDir( const char *dirstr, bool dontWarnInvalid )
       
         _files.clear();
         _dir_opened = false;
-      
-        delete invalid_entries;
-        invalid_entries = NULL;
     }
   
     createIDs();
@@ -320,16 +273,6 @@ void Verzeichnis::closeDir()
 
         _dir_name.clear();
     }
-    if ( invalid_entries != NULL ) {
-        for ( std::vector<FileEntry*>::iterator fe_it2 = invalid_entries->begin();
-              fe_it2 != invalid_entries->end();
-              fe_it2++ ) {
-            delete *fe_it2;
-        }
-          
-        delete invalid_entries;
-        invalid_entries = NULL;
-    }
 }
 
 int Verzeichnis::getSize()
@@ -379,11 +322,6 @@ int Verzeichnis::getUseSize()
     return size;
 }
 
-const std::vector<FileEntry*> *Verzeichnis::getInvalidEntries()
-{
-    return invalid_entries;
-}
-
 void Verzeichnis::buildID2FE()
 {
     if ( _dir_opened == false ||
