@@ -41,12 +41,7 @@ VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_agu
                                                                                           RefCount<AWidth>( new AFontWidth( &aguix,
                                                                                                                             NULL ) ) )
 {
-    std::string cfgfile = Worker::getWorkerConfigDir();
-#ifdef DEBUG
-    cfgfile = NWC::Path::join( cfgfile, "volman_ignore_devices2" );
-#else
-    cfgfile = NWC::Path::join( cfgfile, "volman_ignore_devices" );
-#endif
+    std::string cfgfile = getHiddenDevicesFile();
     m_hide_entries = std::auto_ptr< PersistentStringList >( new PersistentStringList( cfgfile ) );
 
     m_win = std::auto_ptr<AWindow>( new AWindow( &m_aguix,
@@ -68,11 +63,13 @@ VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_agu
     m_lv = dynamic_cast<FieldListView*>( m_cont2->add( new FieldListView( &m_aguix, 0, 0, 
                                                                           200, 200, 0 ),
                                                        0, 0, AContainer::CO_MIN ) );
-    m_lv->setNrOfFields( 3 );
+    m_lv->setNrOfFields( 5 );
     m_lv->setShowHeader( true );
     m_lv->setFieldText( 0, catalog.getLocale( 873 ) );
     m_lv->setFieldText( 1, catalog.getLocale( 874 ) );
     m_lv->setFieldText( 2, catalog.getLocale( 875 ) );
+    m_lv->setFieldText( 3, catalog.getLocale( 912 ) );
+    m_lv->setFieldText( 4, catalog.getLocale( 913 ) );
     m_lv->setHBarState( 2 );
     m_lv->setVBarState( 2 );
     m_lv->setAcceptFocus( true );
@@ -155,7 +152,17 @@ int VolumeManagerUI::mainLoop()
         std::string::size_type last_len = 0;
         for ( int row = 0;; row++ ) {
             if ( m_lv->isValidRow( row ) == false ) break;
-            std::string d = m_lv->getText( row, 0 );
+            std::string d = m_lv->getText( row, 2 );
+            if ( ! d.empty() ) {
+                if ( start_entry.compare( 0, d.length(), d ) == 0 ) {
+                    if ( d.length() > last_len ) {
+                        best_hit = row;
+                        last_len = d.length();
+                    }
+                }
+            }
+
+            d = m_lv->getText( row, 0 );
             if ( ! d.empty() ) {
                 if ( start_entry.compare( 0, d.length(), d ) == 0 ) {
                     if ( d.length() > last_len ) {
@@ -165,26 +172,10 @@ int VolumeManagerUI::mainLoop()
                 }
             }
         }
+
         if ( best_hit >= 0 ) {
             m_lv->setActiveRow( best_hit );
             m_lv->showActive();
-        } else {
-            for ( int row = 0;; row++ ) {
-                if ( m_lv->isValidRow( row ) == false ) break;
-                std::string d = m_lv->getText( row, 2 );
-                if ( ! d.empty() ) {
-                    if ( start_entry.compare( 0, d.length(), d ) == 0 ) {
-                        if ( d.length() > last_len ) {
-                            best_hit = row;
-                            last_len = d.length();
-                        }
-                    }
-                }
-            }
-            if ( best_hit >= 0 ) {
-                m_lv->setActiveRow( best_hit );
-                m_lv->showActive();
-            }
         }
     }
 
@@ -368,6 +359,15 @@ void VolumeManagerUI::updateLV()
             m_lv->setText( row, 0, it1->getSupposedMountPoint() );
             m_lv->setText( row, 1, it1->getDevice() );
             m_lv->setText( row, 2, it1->getMountPoint() );
+            m_lv->setText( row, 3, it1->getLabel() );
+
+            if ( it1->getSize() > 0 ) {
+                std::string ssize;
+                
+                ssize = AGUIXUtils::bytes_to_human_readable_f( it1->getSize() );
+                m_lv->setText( row, 4, ssize );
+            }
+
             m_lv->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
             m_row_to_volume[row] = *it1;
 
@@ -563,3 +563,20 @@ void VolumeManagerUI::editHideList()
 
     updateLV();
 }
+
+std::string VolumeManagerUI::getHiddenDevicesFile()
+{
+    std::string cfgfile = Worker::getWorkerConfigDir();
+#ifdef DEBUG
+    cfgfile = NWC::Path::join( cfgfile, "volman_ignore_devices2" );
+#else
+    cfgfile = NWC::Path::join( cfgfile, "volman_ignore_devices" );
+#endif
+    return cfgfile;
+}
+
+std::list< std::string > VolumeManagerUI::getListOfHiddenDevices()
+{
+    PersistentStringList psl( getHiddenDevicesFile() );
+    return psl.getList();
+}
