@@ -1,6 +1,6 @@
 /* wconfig.h
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2009 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -150,11 +150,10 @@ public:
   int palette();
   int palette(int);
   bool save();
-  bool saveas(char*);
+  bool saveas( const std::string &file );
   bool load();
-  bool loadfrom(char*);
+  bool loadfrom( const std::string &file );
   
-  const char *getHome();
   WCFiletype *getnotyettype();
   WCFiletype *getdirtype();
   WCFiletype *getvoidtype();
@@ -204,6 +203,8 @@ public:
     void layoutAddEntry( LayoutSettings::layoutID_t nv );
     void setLayoutListViewWeight( int nv );
     int getLayoutListViewWeight() const;
+    void setLayoutWeightRelToActive( bool nv );
+    bool getLayoutWeightRelToActive() const;
 
   FlatTypeList *getFlatTypeList();
   typedef enum { MOUSECONF_NORMAL_MODE,
@@ -331,6 +332,8 @@ public:
     std::string getVMMtabFile() const;
     void setVMPartitionFile( const std::string &filename );
     std::string getVMPartitionFile() const;
+    void setVMRequestAction( bool nv );
+    bool getVMRequestAction() const;
 protected:
   char *lang;
   unsigned int rows,columns;
@@ -389,7 +392,6 @@ protected:
   WCFiletype *voidtype; // Nur zum schnelleren Auslesen, muss nicht abgespeichert werden
   WCFiletype *unknowntype; // Nur zum schnelleren Auslesen, muss nicht abgespeichert werden
   
-  char *home;
   Worker *worker;
 
   bool changeTypes( bool allowRemoveUnique );
@@ -484,6 +486,7 @@ protected:
         std::string fstab_file;
         std::string mtab_file;
         std::string part_file;
+        bool request_action;
     } m_vm_settings;
 };
 
