@@ -107,6 +107,7 @@ LayoutPanel::LayoutPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel
     m_weight_sl = NULL;
     m_left_weight_b = NULL;
     m_right_weight_b = NULL;
+    m_weight_active_cb = NULL;
 }
 
 LayoutPanel::~LayoutPanel()
@@ -143,7 +144,7 @@ int LayoutPanel::create()
   lvv = _baseconfig.getLayoutListviewVert();
 
   // global container 1x3
-  ac1 = setContainer( new AContainer( this, 1, 6 ), true );
+  ac1 = setContainer( new AContainer( this, 1, 7 ), true );
   ac1->setMaxSpace( 5 );
   ac1->setBorderWidth( 5 );
 
@@ -252,6 +253,17 @@ int LayoutPanel::create()
   m_weight_sl->setOffset( weight - 1 );
   updateWeightSlider();
 
+  m_weight_active_cb = (ChooseButton*)ac1->add( new ChooseButton( _aguix,
+                                                                  0,
+                                                                  0,
+                                                                  20,
+                                                                  20,
+                                                                  ( _baseconfig.getLayoutWeightRelToActive() == true ) ? 1 : 0,
+                                                                  catalog.getLocale( 908 ),
+                                                                  LABEL_RIGHT,
+                                                                  1,
+                                                                  0 ), 0, 6, AContainer::CO_INCWNR );
+
   setupElementsExample();
   setupElementsLV();
 
@@ -274,6 +286,9 @@ int LayoutPanel::saveValues()
     int o = m_weight_sl->getOffset();
     o = o + 1;
     _baseconfig.setLayoutListViewWeight( o );
+
+    _baseconfig.setLayoutWeightRelToActive( m_weight_active_cb->getState() );
+
     return 0;
 }
 
