@@ -1,6 +1,6 @@
 /* wconfig_volman.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009 Ralf Hoffmann.
+ * Copyright (C) 2009-2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -41,7 +41,7 @@ int VolManPanel::create()
     
     //TODO more info text?
     //TODO add file select buttons
-    AContainer *ac1 = setContainer( new AContainer( this, 1, 2 ), true );
+    AContainer *ac1 = setContainer( new AContainer( this, 1, 3 ), true );
     ac1->setBorderWidth( 5 );
     ac1->setMinSpace( 5 );
     ac1->setMaxSpace( 5 );
@@ -141,6 +141,12 @@ int VolManPanel::create()
                                              HW_VM_PARTS );
     ac1_5->add( new Text( _aguix, 0, 0, str1.c_str(), 1 ),
                 0, 1, AContainer::CO_INCW );
+
+    m_request_action_cb = (ChooseButton*)ac1->add( new ChooseButton( _aguix, 0, 0,
+                                                                     _baseconfig.getVMRequestAction(),
+                                                                     catalog.getLocale( 906 ),
+                                                                     LABEL_RIGHT, 1, 0 ),
+                                                   0, 2, AContainer::CO_INCWNR );
     
     contMaximize( true );
     return 0;
@@ -153,6 +159,7 @@ int VolManPanel::saveValues()
     _baseconfig.setVMFStabFile( m_fstab_sg->getText() );
     _baseconfig.setVMMtabFile( m_mtab_sg->getText() );
     _baseconfig.setVMPartitionFile( m_part_sg->getText() );
+    _baseconfig.setVMRequestAction( m_request_action_cb->getState() );
     return 0;
 }
 
