@@ -40,6 +40,7 @@
 #include "layoutsettings.hh"
 #include "timedtext.hh"
 #include "hw_volume_manager.hh"
+#include "processhandler.hh"
 
 class ListerMode;
 class Lister;
@@ -102,7 +103,8 @@ public:
   int runCommand( const char *exestr,
 		  const char *tmpname,
 		  const char *tmpoutput,
-		  bool inbackground );
+		  bool inbackground,
+                  RefCount< GenericCallback< void > > pea = RefCount< GenericCallback< void > >( NULL ) );
 
   static std::string getWorkerConfigDir();
 
@@ -268,6 +270,14 @@ public:
 
     loff_t m_current_statebar_update_ms;
     void setStatebarUpdate( loff_t time_ms );
+
+    ProcessHandler m_process_handler;
+    void waitForEvent();
+
+    struct worker_event_store {
+        worker_event_store() : check_children( false ) {}
+        bool check_children;
+    } m_event_store;
 };
 
 #endif
