@@ -26,7 +26,7 @@
 #include "workerinitialsettings.hh"
 #include "nwc_path.hh"
 
-#define CATENTRY 909
+#define CATENTRY 915
 #define CATCOMENTRY 59
 #define CATFLAGENTRY 59
 
@@ -596,8 +596,8 @@ The default value here is the active entry and it's already correctly protected!
   catalog[527]=dupstring( "octal:" );
   catalog[528]=dupstring( "Move was canceled but some files were correctly copied!|Shall I delete these files from the source?" );
   catalog[529]=dupstring( "" );
-  catalog[530]=dupstring( "The following files/dirs in the directory %s couldn't be copied|because I didn't get information about them:" );
-  catalog[531]=dupstring( "Can't get information about existing file|%s|because of this error:|%s" );
+  catalog[530]=dupstring( "" );
+  catalog[531]=dupstring( "" );
   catalog[532]=dupstring( "Can't read directory|%s|because of this error:|%s" );
   catalog[533]=dupstring( "Create relative symlink" );
   catalog[534]=dupstring( "Select program" );
@@ -1010,6 +1010,12 @@ match any font." );
   catalog[906]=dupstring( "Ask what to do with new devices" );
   catalog[907]=dupstring( "Permission sort" );
   catalog[908]=dupstring( "Set weight relative to active side" );
+  catalog[909]=dupstring( "No information about %s could be retrieved!|This entry will be skipped." );
+  catalog[910]=dupstring( "<new label>" );
+  catalog[911]=dupstring( "show output (internal viewer)" );
+  catalog[912]=dupstring( "Volume label" );
+  catalog[913]=dupstring( "Volume size" );
+  catalog[914]=dupstring( "Size (human readable)" );
 
 //  catalog[]=dupstring( "" );
   
